<?php
/**
 * GENERIC Module Configurator
 * Defines the Module / Subpage settings GENERIC - - so probably no need to look in here
 * @package WP-Favicons
 * @since 0.4.0
 * @author Edward de Leau <e@leau.net>, http://edward.de.leau.net
 * @copyright GPL 2
 */
namespace leau\co\wp_favicons;

if (!class_exists("Module"))
{
	/**
	 * Holds and defines 1 specific module
	 * One module corresponds to a submenu section and contains multiple plugins
	 * @author Edward de Leau <e@leau.net>, http://edward.de.leau.net
	 * @since 0.4.0
	 */
	class Module
	{
		private $_module_id;

		/**
		 * Constructor
		 * Configures a new module / subpage
		 * @param int $moduleId the module id
		 */
		function __construct($moduleId)
		{
			$this->_module_id = $moduleId;
		}

		/**
		 * Adds a submenu / module / page / screen
		 * This is called by the modules class after instantiation of each module
		 * @uses add_submenu_page {@link http://codex.wordpress.org/Function_Reference/add_submenu_page}
		 * @uses add_settings_section {@link http://codex.wordpress.org/Function_Reference/add_settings_section}
		 */
		function AddSubMenu()
		{

			if (function_exists('add_submenu_page'))
			{
				/* Add a submenu page representing the module */
				add_submenu_page(
				Config::GetMenuSlug(),
				Config::GetModulePageTitle($this->_module_id),
				Config::GetModuleMenuTitle($this->_module_id),
				Config::GetCapability(),
				Config::GetPluginSlug().
					Config::GetModuleMenuSlug($this->_module_id)  . '_page',
				array( $this, 'AddForm' )
				);
			}

			if (function_exists('add_settings_section'))
			{
				/* Add the main settings section to the submenu page / module */
				/* $id, $title, $callback, $page */
				add_settings_section(
				Config::GetPluginSlug().
				Config::GetModuleMenuSlug($this->_module_id) . '_menu_section_main',
				Config::GetModuleSectionHeaderTitle($this->_module_id),
				array($this,'SectionHeader'),
				Config::GetPluginSlug() .
				Config::GetModuleMenuSlug($this->_module_id) . '_page'
				);
			}

			/* Allow plugins to add their sections */
			do_action(Config::GetPluginSlug() .
			Config::GetModuleMenuSlug($this->_module_id) . '_plugins');

			/* Add Help and allow plugins to add their own help screens */
			add_action('contextual_help', array($this,'contextual_help'),1,1);
		}

		/**
		 * Add contextual help for this screen / subpage / module
		 *
		 * @param $text
		 */
		function contextual_help($text)
		{
			$current_screen = get_current_screen();
			/* yes this is a weird id */
			$screen_id 	= strtolower(Config::GetMenuTitle()) . "_page_" . Config::GetPluginSlug() .
			Config::GetModuleMenuSlug($this->_module_id) . "_page";
			if ($current_screen->id == $screen_id)
			{
				$text = Config::GetModuleHelpText($this->_module_id);
			}
			return $text;
		}

		/**
		 * Creates a section header for the module / subpage
		 */
		function SectionHeader()
		{
			//$current_screen = get_current_screen();
			//echo $current_screen ;
			//screen_icon(screen_icon($screen = ''));
			echo Config::GetModuleSectionHeaderText($this->_module_id);
		}

		/**
		 * Generic WordPress Form which uses the settings API
		 * @uses settings_fields
		 * @uses do_settings_sections {@link http://codex.wordpress.org/Function_Reference/do_settings_sections}
		 *  	 (defined in \wp-admin\includes\template.php)
		 * @uses get_current_screen
		 * @uses submit_button
		 *       (defined in \wp-admin\includes\template.php)
		 * @uses settings_errors
		 */
		function AddForm()
		{
			echo "<div class=\"adminform\">";
			settings_errors();
			echo "<form method=\"post\" action=\"options.php\" enctype=\"multipart/form-data\" id=\"plugin_options\">";
			settings_fields(Config::GetSettingsGroupName());
			do_settings_sections(Config::GetPluginSlug() .
			Config::GetModuleMenuSlug($this->_module_id) . '_page');
			echo submit_button( 'Save Changes', 'primary', 'submit', true, NULL );
			echo "<hr />";
			echo "<i>Developers can add more plugins to this page | ";
			echo "Click Help for more information |";
			echo " <a href=\"http://wordpress.org/extend/plugins/wp-favicons/\">homepage</a> | ";
			echo " <a href=\"http://wordpress.org/tags/wp-favicons?forum_id=10\">forum</a> ";
			echo "</i>";
			echo "</form>";
			echo "</div>";
		}

	}
}
